@@ -16,7 +16,7 @@ checkfail()
 # ARGUMENTS #
 #############
 
-MEDIALIBRARY_HASH=180cde9
+MEDIALIBRARY_HASH=15ab842
 
 BUILD_ML=1
 RELEASE=0
@@ -782,7 +782,7 @@ else
     fi
 fi
 if [ "$RELEASE" = 1 ]; then
-    git reset --hard ${MEDIALIBRARY_HASH}
+  git checkout 0.2.x
 fi
 cd ${SRC_DIR}
 echo -e "\e[1m\e[36mCFLAGS:            ${CFLAGS}\e[0m"
