@@ -27,20 +27,16 @@ import android.app.NotificationManager;
 import android.app.PendingIntent;
 import android.content.Context;
 import android.content.Intent;
-import android.graphics.Bitmap;
-import android.net.Uri;
 import android.os.Build;
 import android.support.v4.app.NotificationCompat;
 import android.support.v4.content.ContextCompat;
 
 import org.videolan.medialibrary.media.MediaWrapper;
-import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.helpers.BitmapUtil;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.util.Util;
 
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.List;
 
 @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
@@ -50,7 +46,6 @@ public class RecommendationsService extends IntentService {
     private static final int MAX_RECOMMENDATIONS = 3;
 
     private NotificationManager mNotificationManager;
-    private Context mContext;
 
     public RecommendationsService() {
         super("RecommendationService");
@@ -59,9 +54,8 @@ public class RecommendationsService extends IntentService {
     @Override
     public void onCreate() {
         super.onCreate();
-        mContext = this;
-            mNotificationManager = (NotificationManager)
-                    getApplicationContext().getSystemService(Context.NOTIFICATION_SERVICE);
+        mNotificationManager = (NotificationManager)
+                getApplicationContext().getSystemService(Context.NOTIFICATION_SERVICE);
     }
 
     @Override
@@ -73,14 +67,9 @@ public class RecommendationsService extends IntentService {
         if (movie == null)
             return;
 
-        //TODO
-//        if (mBackgroundUri != movie.getBackgroundUri()) {
-//            extras.putString(EXTRA_BACKGROUND_IMAGE_URL, movie.getBackgroundUri());
-//        }
-
         // build the recommendation as a Notification object
         Notification notification = new NotificationCompat.BigPictureStyle(
-                new NotificationCompat.Builder(mContext)
+                new NotificationCompat.Builder(RecommendationsService.this)
                         .setContentTitle(movie.getTitle())
                         .setContentText(movie.getDescription())
                         .setContentInfo(getString(R.string.app_name))
@@ -99,7 +88,7 @@ public class RecommendationsService extends IntentService {
     }
 
     private PendingIntent buildPendingIntent(MediaWrapper mediaWrapper, int id) {
-        Intent intent = new Intent(mContext, VideoPlayerActivity.class);
+        Intent intent = new Intent(RecommendationsService.this, VideoPlayerActivity.class);
         intent.setAction(VideoPlayerActivity.PLAY_FROM_VIDEOGRID);
         intent.putExtra(VideoPlayerActivity.PLAY_EXTRA_ITEM_LOCATION, mediaWrapper.getUri());
         intent.putExtra(VideoPlayerActivity.PLAY_EXTRA_ITEM_TITLE, mediaWrapper.getTitle());
@@ -108,21 +97,21 @@ public class RecommendationsService extends IntentService {
         return PendingIntent.getActivity(this, id, intent, PendingIntent.FLAG_UPDATE_CURRENT);
     }
 
-    private boolean doRecommendations() {
+    private void doRecommendations() {
         mNotificationManager.cancelAll();
-        int id = 0;
-        List<MediaWrapper> videoList = Arrays.asList(VLCApplication.getMLInstance().getVideos());
-        if (Util.isListEmpty(videoList))
-            return false;
-        Bitmap pic;
-        Collections.shuffle(videoList);
-        for (MediaWrapper mediaWrapper : videoList){
-            pic = AudioUtil.readCoverBitmap(Uri.decode(mediaWrapper.getArtworkMrl()), 256);
-            if (pic != null && pic.getByteCount() > 4)
-                buildRecommendation(mediaWrapper, ++id, Notification.PRIORITY_DEFAULT);
-            if (id == MAX_RECOMMENDATIONS)
-                break;
-        }
-        return true;
+        VLCApplication.runBackground(new Runnable() {
+            @Override
+            public void run() {
+                int id = 0;
+                List<MediaWrapper> videoList = Arrays.asList(VLCApplication.getMLInstance().getRecentVideos());
+                if (Util.isListEmpty(videoList))
+                    return;
+                for (MediaWrapper mediaWrapper : videoList){
+                    buildRecommendation(mediaWrapper, ++id, Notification.PRIORITY_DEFAULT);
+                    if (id == MAX_RECOMMENDATIONS)
+                        break;
+                }
+            }
+        });
     }
 }
